Association Rules Mining
************************

.. automodule:: ibmdbpy.learn.association_rules

Initiate model
==============

.. currentmodule:: ibmdbpy.learn.association_rules
.. highlight:: python

Create an AssociationRules object
---------------------------------

.. autoclass:: AssociationRules


   .. automethod:: __init__


Get parameters
--------------
.. automethod:: AssociationRules.get_params

Set parameters
--------------
.. automethod:: AssociationRules.set_params

.. rubric:: Methods

Fit, prune and predict
======================

fit
---
.. automethod:: AssociationRules.fit

prune
-----
.. automethod:: AssociationRules.prune

predict
-------
.. automethod:: AssociationRules.predict

fit_predict
-----------
.. automethod:: AssociationRules.fit_predict

Explore result
==============

describe
--------
.. automethod:: AssociationRules.describe

_retrieve_AssociationRules_Model
--------------------------------
.. automethod:: AssociationRules._retrieve_AssociationRules_Model